@@ -20,16 +20,14 @@
 // Main function
 int main(int argc, char *argv[])
 {
-  // Fixes blurry icons with fractional scaling
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-  QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-#endif
   QApplication app(argc, argv);
 
   KLocalizedString::setApplicationDomain("ktuberling");
 
   KAboutData aboutData( QStringLiteral("ktuberling"), i18n("KTuberling"), 
-          KTUBERLING_VERSION_STRING, i18n("Potato game for kids"), KAboutLicense::GPL,
+          QStringLiteral(KTUBERLING_VERSION_STRING),
+          i18n("Potato game for kids"),
+          KAboutLicense::GPL,
           i18n("(c) 1999-2009, The KTuberling Developers"));
   aboutData.addAuthor(i18n("Albert Astals Cid"), i18n("Maintainer"), QStringLiteral("aacid@kde.org"));
   aboutData.addAuthor(i18n("Éric Bischoff"), i18n("Former Developer"), QStringLiteral("ebischoff@nerim.net"));
@@ -39,11 +37,14 @@ int main(int argc, char *argv[])
   aboutData.addCredit(i18n("Roger Larsson"), i18n("Sounds tuning"), QStringLiteral("roger.larsson@norran.net"));
   aboutData.addCredit(i18n("Dolores Almansa"), i18n("New artwork"), QStringLiteral("dolores.almansa@corazondemaria.org"));
   aboutData.setHomepage(QStringLiteral("https://apps.kde.org/ktuberling"));
-  QCommandLineParser parser;
-  KAboutData::setApplicationData(aboutData);
-  KCrash::initialize();
-  parser.addPositionalArgument(QStringLiteral("tuberling-file"), i18n("Potato to open"));
 
+  KAboutData::setApplicationData(aboutData);
+  QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("ktuberling")));
+
+  KCrash::initialize();
+
+  QCommandLineParser parser;
+  parser.addPositionalArgument(QStringLiteral("tuberling-file"), i18n("Potato to open"));
   aboutData.setupCommandLine(&parser);
   parser.process(app);
   aboutData.processCommandLine(&parser);
@@ -61,7 +62,5 @@ int main(int argc, char *argv[])
 
   }
 
-  app.setWindowIcon(QIcon::fromTheme(QStringLiteral("ktuberling")));
-
   return app.exec();
 }
